@@ -107,13 +107,13 @@ HtmlDocGenerator::generate_bottom()
 void
 HtmlDocGenerator::generate_start_doc()
 {
-  generateln( "<pre>" ) ;
-  generateln( "<tt>" ) ;
+  generate( "<pre>" ) ;
+  generate( "<tt>" ) ;
 }
 
 void
 HtmlDocGenerator::generate_end_doc()
 {
-  generateln( "</tt>" ) ;
+  generate( "</tt>" ) ;
   generateln( "</pre>" ) ;
 }
