@@ -24,20 +24,26 @@
 
 #define NUM_OF_CHARS 256
 
-#include <iostream>
+#include <string>
+#include <boost/regex.hpp>
 
-using std::ostream;
+#include "textformatter.h"
 
-class CharTranslator
+class CharTranslator : public TextFormatter
 {
  protected:
-  char *characters[NUM_OF_CHARS];
+   unsigned int counter;
+   std::string translation_exp; // what to translate
+   std::string translation_format; // translate into
+   boost::regex *reg_exp;
 
+   virtual const std::string preformat(const std::string &text); 
+   
  public:
-  CharTranslator();
+  CharTranslator(TextFormatter *f = 0);
+  virtual ~CharTranslator();
 
   void set_translation(char, const char *);
-  virtual void translate(ostream *, const char *);
 } ;
 
 #endif // _CHARTRANSLATOR_H
