@@ -32,9 +32,11 @@ class DocGenerator
 {
  protected:
   string title;
+  bool gen_source_highlight_version;
 
  public:
-  DocGenerator(const string &s) : title (s) {}
+  DocGenerator(const string &s) : title (s),
+    gen_source_highlight_version (true) {}
   virtual ~DocGenerator() {}
 
   virtual void generate_top() {}
@@ -45,6 +47,8 @@ class DocGenerator
 
   virtual void generate(const string &);
   virtual void generateln(const string &);
+
+  void set_gen_version(bool b) { gen_source_highlight_version = b; } 
 };
 
 #endif // DOCGENERATOR_H
