@@ -26,10 +26,9 @@
 #include "docgenerator.h"
 #include "chartranslator.h"
 #include "textgen.h"
+#include "colormap.h"
 
 // global
-#include "generators.h"
-#include "globalcolormap.h"
 #include "maingeneratormap.h"
 
 GeneratorFactory::GeneratorFactory(const string &t) :
@@ -41,6 +40,9 @@ GeneratorFactory::~ GeneratorFactory()
 {
   if (generatormap)
     delete generatormap;
+
+  if (MapOfColors)
+    delete MapOfColors;
 }
 
 CharTranslator *
@@ -64,12 +66,6 @@ GeneratorFactory::createGenerators()
   MapOfColors = createColorMap ();
   generatormap = createGeneratorMap();
 
-  TextGenerator *GlobalGenerator = new TextGenerator;
-
-  TextGenerator *final_decorator;
-
-  final_decorator = GlobalGenerator;
-
   const Tags *tags = getTags();
 
   TextGenerator *text_gen;
@@ -82,8 +78,6 @@ GeneratorFactory::createGenerators()
   // set the normal generator as the default generator
   TextGenerator *normal = createDefaultGenerator ();
   generatormap->setDefaultGenerator(normal);
-
-  GlobalDocGenerator = createDocGenerator ();
 }
 
 #define GET_DECORATED( d ) ( d ? d : final_dec )
@@ -109,7 +103,7 @@ TextGenerator *
 GeneratorFactory::createGenerator( const Tag *tag )
 {
   resetTagBuffers();
-  
+
   const string &color = tag->GetColor() ;
   if ( color.size () )
     {
