@@ -72,18 +72,6 @@ GeneratorMap::generate( const std::string &elem, const std::string &s )
   outputbuffer->output(getGenerator(elem)->generate(s.c_str()));
 }
 
-void
-GeneratorMap::generate( const std::string &elem, const std::string &s, int start, int end )
-{
-  outputbuffer->output(getGenerator(elem)->generate(s.c_str(), start, end));
-}
-
-void
-GeneratorMap::generate_preproc(const std::string &elem, const std::string &s)
-{
-  outputbuffer->output(getGenerator(elem)->generate_preproc(s.c_str()));
-}
-
 void
 GeneratorMap::generateln( const std::string &elem, const std::string &s )
 {
@@ -95,16 +83,3 @@ GeneratorMap::generateEntire( const std::string &elem, const std::string &s )
 {
   outputbuffer->output(getGenerator(elem)->generateEntire(s.c_str()));
 }
-
-void
-GeneratorMap::beginText( const std::string &elem, const std::string &s )
-{
-  outputbuffer->output(getGenerator(elem)->beginText(s.c_str()));
-}
-
-void
-GeneratorMap::endText( const std::string &elem, const std::string &s )
-{
-  outputbuffer->output(getGenerator(elem)->endText(s.c_str()));
-}
-
