@@ -41,15 +41,8 @@ class GeneratorMap
   void setDefaultGenerator(TextGenerator *g);
 
   void generate( const std::string &elem, const std::string &s );
-  void generate( const std::string &elem, const std::string &s, int start, int end );
-  void generate_preproc(const std::string &elem, const std::string &s);
-
   void generateln( const std::string &elem, const std::string &s );
-
   void generateEntire( const std::string &elem, const std::string &s );
-
-  void beginText( const std::string &elem, const std::string &s );
-  void endText( const std::string &elem, const std::string &s );
 };
 
 #endif
