@@ -20,6 +20,8 @@
 
 // messages.cc
 
+#include <stdlib.h>
+
 #include "messages.h"
 
 static Messages *_messager = 0 ;
@@ -29,12 +31,23 @@ void printMessage( const char *s, ostream &stream ) {
     _messager->printMessage(s,stream) ;
 }
 
+void printMessage( const std::string &s, ostream &stream ) {
+  if ( _messager )
+    _messager->printMessage(s,stream) ;
+}
+
 void
 printMessage_noln( const char *s, ostream &stream ) {
   if ( _messager )
     _messager->printMessage_noln(s,stream) ;
 }
 
+void
+printMessage_noln( const std::string &s, ostream &stream ) {
+  if ( _messager )
+    _messager->printMessage_noln(s,stream) ;
+}
+
 void printWarning( const char *s, ostream &stream ) {
   if ( _messager )
     _messager->printWarning(s,stream) ;
@@ -44,7 +57,27 @@ void printError( const char *s, ostream &stream ) {
   stream << s << endl;
 }
 
+void printError( const std::string &s, ostream &stream ) {
+  stream << s << endl;
+}
+
+void printError(const std::string &filename, unsigned int line, const std::string &error, ostream & stream)
+{
+  stream << filename << ":" << line << ": " << error << endl;
+}
+
 void setMessager( Messages *m ) {
   if ( m )
     _messager = m ;
 }
+
+void memory_exhausted()
+{
+  cerr << "no more free memory" << endl;
+}
+
+void exitError(const std::string &error)
+{
+  cerr << error << endl;
+  exit(EXIT_FAILURE);
+}
