@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875.  */
+/* A Bison parser, made by GNU Bison 1.875d.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -45,6 +45,15 @@
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
+/* If NAME_PREFIX is specified substitute the variables and functions
+   names.  */
+#define yyparse opsc_parse
+#define yylex   opsc_lex
+#define yyerror opsc_error
+#define yylval  opsc_lval
+#define yychar  opsc_char
+#define yydebug opsc_debug
+#define yynerrs opsc_nerrs
 
 
 /* Tokens.  */
@@ -70,7 +79,7 @@
 
 
 /* Copy the first part of user declarations.  */
-
+#line 1 "./optparser.yy"
 
 /*
  * Copyright (C) 1999, 2000, 2001 Lorenzo Bettini <bettini@gnu.org>
@@ -93,8 +102,8 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <iostream>
+#include <string>
 
 #include "my_sstream.h"
 
@@ -103,15 +112,15 @@
 #include "keys.h"
 #include "messages.h"
 #include "parsetags.h"
+#include "fileutil.h"
 
 using std::cerr;
 
-static int opsc_parse() ;
-static void opsc_error( char *s ) ;
+static int yyparse() ;
+static void yyerror( char *s ) ;
 
 int line = 1 ;
 
-static FILE *openTagsFile() ;
 static void add_tag(Tags *tags, Tag *t);
 
 extern int opsc_lex() ;
@@ -133,17 +142,17 @@ extern FILE *opsc_in ;
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-
+#line 49 "./optparser.yy"
 typedef union YYSTYPE {
   int tok ; /* command */
-  char * string ; /* string : id, ... */
+  const std::string * string ; /* string : id, ... */
   int flag ;
   Tag *tag ;
   Tags *tags ;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-
-# define opsc_stype YYSTYPE /* obsolescent; will be withdrawn */
+#line 155 "optparser.cc"
+# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
 #endif
@@ -154,22 +163,29 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-
+#line 167 "optparser.cc"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
+# ifndef YYFREE
+#  define YYFREE free
+# endif
+# ifndef YYMALLOC
+#  define YYMALLOC malloc
+# endif
+
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
 
-# if YYSTACK_USE_ALLOCA
-#  define YYSTACK_ALLOC alloca
+# ifdef YYSTACK_USE_ALLOCA
+#  if YYSTACK_USE_ALLOCA
+#   define YYSTACK_ALLOC alloca
+#  endif
 # else
-#  ifndef YYSTACK_USE_ALLOCA
-#   if defined (alloca) || defined (_ALLOCA_H)
-#    define YYSTACK_ALLOC alloca
-#   else
-#    ifdef __GNUC__
-#     define YYSTACK_ALLOC __builtin_alloca
-#    endif
+#  if defined (alloca) || defined (_ALLOCA_H)
+#   define YYSTACK_ALLOC alloca
+#  else
+#   ifdef __GNUC__
+#    define YYSTACK_ALLOC __builtin_alloca
 #   endif
 #  endif
 # endif
@@ -182,21 +198,21 @@ typedef union YYSTYPE {
 #   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
 #   define YYSIZE_T size_t
 #  endif
-#  define YYSTACK_ALLOC malloc
-#  define YYSTACK_FREE free
+#  define YYSTACK_ALLOC YYMALLOC
+#  define YYSTACK_FREE YYFREE
 # endif
 #endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */
 
 
 #if (! defined (yyoverflow) \
      && (! defined (__cplusplus) \
-	 || (YYSTYPE_IS_TRIVIAL)))
+	 || (defined (YYSTYPE_IS_TRIVIAL) && YYSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  short opsc_ss;
-  YYSTYPE opsc_vs;
+  short int yyss;
+  YYSTYPE yyvs;
   };
 
 /* The size of the maximum gap between one aligned stack and the next.  */
@@ -205,13 +221,13 @@ union yyalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
+     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
    not overlap.  */
 # ifndef YYCOPY
-#  if 1 < __GNUC__
+#  if defined (__GNUC__) && 1 < __GNUC__
 #   define YYCOPY(To, From, Count) \
       __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
 #  else
@@ -235,9 +251,9 @@ union yyalloc
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, opsc_size);				\
+	YYCOPY (&yyptr->Stack, Stack, yysize);				\
 	Stack = &yyptr->Stack;						\
-	yynewbytes = opsc_stacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
+	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
     while (0)
@@ -245,9 +261,9 @@ union yyalloc
 #endif
 
 #if defined (__STDC__) || defined (__cplusplus)
-   typedef signed char opsc_signed_char;
+   typedef signed char yysigned_char;
 #else
-   typedef short opsc_signed_char;
+   typedef short int yysigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -313,7 +329,7 @@ static const unsigned char yyprhs[] =
 };
 
 /* YYRHS -- A `-1'-separated list of the rules' RHS. */
-static const opsc_signed_char yyrhs[] =
+static const yysigned_char yyrhs[] =
 {
       11,     0,    -1,    12,    -1,    12,    13,    -1,    13,    -1,
       -1,     6,     7,    14,    15,     8,    -1,    15,     9,    16,
@@ -323,8 +339,8 @@ static const opsc_signed_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
-       0,    66,    66,    69,    70,    74,    73,    85,    86,    89,
-      90,    91,    92
+       0,    66,    66,    69,    70,    74,    73,    87,    88,    91,
+      92,    93,    94
 };
 #endif
 
@@ -333,8 +349,8 @@ static const unsigned char yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals. */
 static const char *const yytname[] =
 {
-  "$end", "error", "$undefined", "BOLD", "ITALICS", "UNDERLINE", "KEY", 
-  "COLOR", "';'", "','", "$accept", "globaltags", "options", "option", 
+  "$end", "error", "$undefined", "BOLD", "ITALICS", "UNDERLINE", "KEY",
+  "COLOR", "';'", "','", "$accept", "globaltags", "options", "option",
   "@1", "values", "value", 0
 };
 #endif
@@ -342,7 +358,7 @@ static const char *const yytname[] =
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short yytoknum[] =
+static const unsigned short int yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,    59,    44
 };
@@ -365,14 +381,14 @@ static const unsigned char yyr2[] =
 /* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
    STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
    means the default is an error.  */
-static const unsigned char opsc_defact[] =
+static const unsigned char yydefact[] =
 {
        0,     0,     0,     2,     4,     5,     1,     3,     9,    10,
       11,    12,     0,     8,     6,     9,     7
 };
 
 /* YYDEFGOTO[NTERM-NUM]. */
-static const opsc_signed_char opsc_defgoto[] =
+static const yysigned_char yydefgoto[] =
 {
       -1,     2,     3,     4,     8,    12,    13
 };
@@ -380,14 +396,14 @@ static const opsc_signed_char opsc_defgoto[] =
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
 #define YYPACT_NINF -7
-static const opsc_signed_char opsc_pact[] =
+static const yysigned_char yypact[] =
 {
       -1,     0,     6,    -1,    -7,    -7,    -7,    -7,    -3,    -7,
       -7,    -7,    -5,    -7,    -7,    -3,    -7
 };
 
 /* YYPGOTO[NTERM-NUM].  */
-static const opsc_signed_char opsc_pgoto[] =
+static const yysigned_char yypgoto[] =
 {
       -7,    -7,    -7,     5,    -7,    -7,    -6
 };
@@ -397,19 +413,19 @@ static const opsc_signed_char opsc_pgoto[] =
    number is the opposite.  If zero, do what YYDEFACT says.
    If YYTABLE_NINF, syntax error.  */
 #define YYTABLE_NINF -1
-static const unsigned char opsc_table[] =
+static const unsigned char yytable[] =
 {
        9,    10,    11,    14,    15,     1,     6,     5,     7,    16
 };
 
-static const unsigned char opsc_check[] =
+static const unsigned char yycheck[] =
 {
        3,     4,     5,     8,     9,     6,     0,     7,     3,    15
 };
 
 /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
    symbol of state STATE-NUM.  */
-static const unsigned char opsc_stos[] =
+static const unsigned char yystos[] =
 {
        0,     6,    11,    12,    13,     7,     0,    13,    14,     3,
        4,     5,    15,    16,     8,     9,    16
@@ -432,16 +448,16 @@ static const unsigned char opsc_stos[] =
 #endif
 
 #define yyerrok		(yyerrstatus = 0)
-#define yyclearin	(opsc_char = YYEMPTY)
+#define yyclearin	(yychar = YYEMPTY)
 #define YYEMPTY		(-2)
 #define YYEOF		0
 
 #define YYACCEPT	goto yyacceptlab
 #define YYABORT		goto yyabortlab
-#define YYERROR		goto yyerrlab1
+#define YYERROR		goto yyerrorlab
 
 
-/* Like YYERROR except do call opsc_error.  This remains here temporarily
+/* Like YYERROR except do call yyerror.  This remains here temporarily
    to ease the transition to the new meaning of YYERROR, for GCC.
    Once GCC version 2 has supplanted version 1, this can go.  */
 
@@ -451,17 +467,17 @@ static const unsigned char opsc_stos[] =
 
 #define YYBACKUP(Token, Value)					\
 do								\
-  if (opsc_char == YYEMPTY && opsc_len == 1)				\
+  if (yychar == YYEMPTY && yylen == 1)				\
     {								\
-      opsc_char = (Token);						\
-      opsc_lval = (Value);						\
-      yytoken = YYTRANSLATE (opsc_char);				\
+      yychar = (Token);						\
+      yylval = (Value);						\
+      yytoken = YYTRANSLATE (yychar);				\
       YYPOPSTACK;						\
       goto yybackup;						\
     }								\
   else								\
     { 								\
-      opsc_error ("syntax error: cannot back up");\
+      yyerror ("syntax error: cannot back up");\
       YYERROR;							\
     }								\
 while (0)
@@ -473,19 +489,19 @@ while (0)
    are run).  */
 
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)         \
-  Current.first_line   = Rhs[1].first_line;      \
-  Current.first_column = Rhs[1].first_column;    \
-  Current.last_line    = Rhs[N].last_line;       \
-  Current.last_column  = Rhs[N].last_column;
+# define YYLLOC_DEFAULT(Current, Rhs, N)		\
+   ((Current).first_line   = (Rhs)[1].first_line,	\
+    (Current).first_column = (Rhs)[1].first_column,	\
+    (Current).last_line    = (Rhs)[N].last_line,	\
+    (Current).last_column  = (Rhs)[N].last_column)
 #endif
 
-/* YYLEX -- calling `opsc_lex' with the right arguments.  */
+/* YYLEX -- calling `yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
-# define YYLEX opsc_lex (YYLEX_PARAM)
+# define YYLEX yylex (YYLEX_PARAM)
 #else
-# define YYLEX opsc_lex ()
+# define YYLEX yylex ()
 #endif
 
 /* Enable debugging if requested.  */
@@ -498,22 +514,22 @@ while (0)
 
 # define YYDPRINTF(Args)			\
 do {						\
-  if (opsc_debug)					\
+  if (yydebug)					\
     YYFPRINTF Args;				\
 } while (0)
 
 # define YYDSYMPRINT(Args)			\
 do {						\
-  if (opsc_debug)					\
-    opsc_symprint Args;				\
+  if (yydebug)					\
+    yysymprint Args;				\
 } while (0)
 
 # define YYDSYMPRINTF(Title, Token, Value, Location)		\
 do {								\
-  if (opsc_debug)							\
+  if (yydebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
-      opsc_symprint (stderr, 					\
+      yysymprint (stderr, 					\
                   Token, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
@@ -521,17 +537,17 @@ do {								\
 
 /*------------------------------------------------------------------.
 | yy_stack_print -- Print the state stack from its BOTTOM up to its |
-| TOP (cinluded).                                                   |
+| TOP (included).                                                   |
 `------------------------------------------------------------------*/
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yy_stack_print (short *bottom, short *top)
+yy_stack_print (short int *bottom, short int *top)
 #else
 static void
 yy_stack_print (bottom, top)
-    short *bottom;
-    short *top;
+    short int *bottom;
+    short int *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -542,7 +558,7 @@ yy_stack_print (bottom, top)
 
 # define YY_STACK_PRINT(Bottom, Top)				\
 do {								\
-  if (opsc_debug)							\
+  if (yydebug)							\
     yy_stack_print ((Bottom), (Top));				\
 } while (0)
 
@@ -553,32 +569,32 @@ do {								\
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yy_reduce_print (int opsc_rule)
+yy_reduce_print (int yyrule)
 #else
 static void
-yy_reduce_print (opsc_rule)
-    int opsc_rule;
+yy_reduce_print (yyrule)
+    int yyrule;
 #endif
 {
   int yyi;
-  unsigned int opsc_lineno = yyrline[opsc_rule];
+  unsigned int yylno = yyrline[yyrule];
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
-             opsc_rule - 1, opsc_lineno);
+             yyrule - 1, yylno);
   /* Print the symbols being reduced, and their result.  */
-  for (yyi = yyprhs[opsc_rule]; 0 <= yyrhs[yyi]; yyi++)
+  for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
     YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
-  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[opsc_rule]]);
+  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[yyrule]]);
 }
 
 # define YY_REDUCE_PRINT(Rule)		\
 do {					\
-  if (opsc_debug)				\
+  if (yydebug)				\
     yy_reduce_print (Rule);		\
 } while (0)
 
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
-int opsc_debug;
+int yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
 # define YYDSYMPRINT(Args)
@@ -600,7 +616,7 @@ int opsc_debug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if YYMAXDEPTH == 0
+#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
 # undef YYMAXDEPTH
 #endif
 
@@ -612,48 +628,48 @@ int opsc_debug;
 
 #if YYERROR_VERBOSE
 
-# ifndef opsc_strlen
+# ifndef yystrlen
 #  if defined (__GLIBC__) && defined (_STRING_H)
-#   define opsc_strlen strlen
+#   define yystrlen strlen
 #  else
 /* Return the length of YYSTR.  */
 static YYSIZE_T
 #   if defined (__STDC__) || defined (__cplusplus)
-opsc_strlen (const char *opsc_str)
+yystrlen (const char *yystr)
 #   else
-opsc_strlen (opsc_str)
-     const char *opsc_str;
+yystrlen (yystr)
+     const char *yystr;
 #   endif
 {
-  register const char *opsc_s = opsc_str;
+  register const char *yys = yystr;
 
-  while (*opsc_s++ != '\0')
+  while (*yys++ != '\0')
     continue;
 
-  return opsc_s - opsc_str - 1;
+  return yys - yystr - 1;
 }
 #  endif
 # endif
 
-# ifndef opsc_stpcpy
+# ifndef yystpcpy
 #  if defined (__GLIBC__) && defined (_STRING_H) && defined (_GNU_SOURCE)
-#   define opsc_stpcpy stpcpy
+#   define yystpcpy stpcpy
 #  else
 /* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
    YYDEST.  */
 static char *
 #   if defined (__STDC__) || defined (__cplusplus)
-opsc_stpcpy (char *yydest, const char *opsc_src)
+yystpcpy (char *yydest, const char *yysrc)
 #   else
-opsc_stpcpy (yydest, opsc_src)
+yystpcpy (yydest, yysrc)
      char *yydest;
-     const char *opsc_src;
+     const char *yysrc;
 #   endif
 {
   register char *yyd = yydest;
-  register const char *opsc_s = opsc_src;
+  register const char *yys = yysrc;
 
-  while ((*yyd++ = *opsc_s++) != '\0')
+  while ((*yyd++ = *yys++) != '\0')
     continue;
 
   return yyd - 1;
@@ -672,34 +688,34 @@ opsc_stpcpy (yydest, opsc_src)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-opsc_symprint (FILE *opsc_output, int yytype, YYSTYPE *opsc_valuep)
+yysymprint (FILE *yyoutput, int yytype, YYSTYPE *yyvaluep)
 #else
 static void
-opsc_symprint (opsc_output, yytype, opsc_valuep)
-    FILE *opsc_output;
+yysymprint (yyoutput, yytype, yyvaluep)
+    FILE *yyoutput;
     int yytype;
-    YYSTYPE *opsc_valuep;
+    YYSTYPE *yyvaluep;
 #endif
 {
   /* Pacify ``unused variable'' warnings.  */
-  (void) opsc_valuep;
+  (void) yyvaluep;
 
   if (yytype < YYNTOKENS)
     {
-      YYFPRINTF (opsc_output, "token %s (", yytname[yytype]);
+      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
 # ifdef YYPRINT
-      YYPRINT (opsc_output, yytoknum[yytype], *opsc_valuep);
+      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
 # endif
     }
   else
-    YYFPRINTF (opsc_output, "nterm %s (", yytname[yytype]);
+    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
 
   switch (yytype)
     {
       default:
         break;
     }
-  YYFPRINTF (opsc_output, ")");
+  YYFPRINTF (yyoutput, ")");
 }
 
 #endif /* ! YYDEBUG */
@@ -709,16 +725,16 @@ opsc_symprint (opsc_output, yytype, opsc_valuep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yydestruct (int yytype, YYSTYPE *opsc_valuep)
+yydestruct (int yytype, YYSTYPE *yyvaluep)
 #else
 static void
-yydestruct (yytype, opsc_valuep)
+yydestruct (yytype, yyvaluep)
     int yytype;
-    YYSTYPE *opsc_valuep;
+    YYSTYPE *yyvaluep;
 #endif
 {
   /* Pacify ``unused variable'' warnings.  */
-  (void) opsc_valuep;
+  (void) yyvaluep;
 
   switch (yytype)
     {
@@ -733,55 +749,55 @@ yydestruct (yytype, opsc_valuep)
 
 #ifdef YYPARSE_PARAM
 # if defined (__STDC__) || defined (__cplusplus)
-int opsc_parse (void *YYPARSE_PARAM);
+int yyparse (void *YYPARSE_PARAM);
 # else
-int opsc_parse ();
+int yyparse ();
 # endif
 #else /* ! YYPARSE_PARAM */
 #if defined (__STDC__) || defined (__cplusplus)
-int opsc_parse (void);
+int yyparse (void);
 #else
-int opsc_parse ();
+int yyparse ();
 #endif
 #endif /* ! YYPARSE_PARAM */
 
 
 
 /* The lookahead symbol.  */
-int opsc_char;
+int yychar;
 
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE opsc_lval;
+YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
-int opsc_nerrs;
+int yynerrs;
 
 
 
 /*----------.
-| opsc_parse.  |
+| yyparse.  |
 `----------*/
 
 #ifdef YYPARSE_PARAM
 # if defined (__STDC__) || defined (__cplusplus)
-int opsc_parse (void *YYPARSE_PARAM)
+int yyparse (void *YYPARSE_PARAM)
 # else
-int opsc_parse (YYPARSE_PARAM)
+int yyparse (YYPARSE_PARAM)
   void *YYPARSE_PARAM;
 # endif
 #else /* ! YYPARSE_PARAM */
 #if defined (__STDC__) || defined (__cplusplus)
 int
-opsc_parse (void)
+yyparse (void)
 #else
 int
-opsc_parse ()
+yyparse ()
 
 #endif
 #endif
 {
   
-  register int opsc_state;
+  register int yystate;
   register int yyn;
   int yyresult;
   /* Number of tokens to shift before error messages enabled.  */
@@ -790,79 +806,80 @@ opsc_parse ()
   int yytoken = 0;
 
   /* Three stacks and their tools:
-     `opsc_ss': related to states,
-     `opsc_vs': related to semantic values,
+     `yyss': related to states,
+     `yyvs': related to semantic values,
      `yyls': related to locations.
 
      Refer to the stacks thru separate pointers, to allow yyoverflow
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short	opsc_ssa[YYINITDEPTH];
-  short *opsc_ss = opsc_ssa;
-  register short *opsc_ssp;
+  short int yyssa[YYINITDEPTH];
+  short int *yyss = yyssa;
+  register short int *yyssp;
 
   /* The semantic value stack.  */
-  YYSTYPE opsc_vsa[YYINITDEPTH];
-  YYSTYPE *opsc_vs = opsc_vsa;
-  register YYSTYPE *opsc_vsp;
+  YYSTYPE yyvsa[YYINITDEPTH];
+  YYSTYPE *yyvs = yyvsa;
+  register YYSTYPE *yyvsp;
 
 
 
-#define YYPOPSTACK   (opsc_vsp--, opsc_ssp--)
+#define YYPOPSTACK   (yyvsp--, yyssp--)
 
-  YYSIZE_T opsc_stacksize = YYINITDEPTH;
+  YYSIZE_T yystacksize = YYINITDEPTH;
 
   /* The variables used to return semantic value and location from the
      action routines.  */
-  YYSTYPE opsc_val;
+  YYSTYPE yyval;
 
 
   /* When reducing, the number of symbols on the RHS of the reduced
      rule.  */
-  int opsc_len;
+  int yylen;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
 
-  opsc_state = 0;
+  yystate = 0;
   yyerrstatus = 0;
-  opsc_nerrs = 0;
-  opsc_char = YYEMPTY;		/* Cause a token to be read.  */
+  yynerrs = 0;
+  yychar = YYEMPTY;		/* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
 
-  opsc_ssp = opsc_ss;
-  opsc_vsp = opsc_vs;
+  yyssp = yyss;
+  yyvsp = yyvs;
 
-  goto opsc_setstate;
+
+  goto yysetstate;
 
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in opsc_state.  |
+| yynewstate -- Push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
  yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed. so pushing a state here evens the stacks.
      */
-  opsc_ssp++;
+  yyssp++;
 
- opsc_setstate:
-  *opsc_ssp = opsc_state;
+ yysetstate:
+  *yyssp = yystate;
 
-  if (opsc_ss + opsc_stacksize - 1 <= opsc_ssp)
+  if (yyss + yystacksize - 1 <= yyssp)
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T opsc_size = opsc_ssp - opsc_ss + 1;
+      YYSIZE_T yysize = yyssp - yyss + 1;
 
 #ifdef yyoverflow
       {
 	/* Give user a chance to reallocate the stack. Use copies of
 	   these so that the &'s don't force the real ones into
 	   memory.  */
-	YYSTYPE *opsc_vs1 = opsc_vs;
-	short *opsc_ss1 = opsc_ss;
+	YYSTYPE *yyvs1 = yyvs;
+	short int *yyss1 = yyss;
 
 
 	/* Each stack pointer address is followed by the size of the
@@ -870,53 +887,53 @@ opsc_parse ()
 	   conditional around just the two extra args, but that might
 	   be undefined if yyoverflow is a macro.  */
 	yyoverflow ("parser stack overflow",
-		    &opsc_ss1, opsc_size * sizeof (*opsc_ssp),
-		    &opsc_vs1, opsc_size * sizeof (*opsc_vsp),
+		    &yyss1, yysize * sizeof (*yyssp),
+		    &yyvs1, yysize * sizeof (*yyvsp),
 
-		    &opsc_stacksize);
+		    &yystacksize);
 
-	opsc_ss = opsc_ss1;
-	opsc_vs = opsc_vs1;
+	yyss = yyss1;
+	yyvs = yyvs1;
       }
 #else /* no yyoverflow */
 # ifndef YYSTACK_RELOCATE
       goto yyoverflowlab;
 # else
       /* Extend the stack our own way.  */
-      if (YYMAXDEPTH <= opsc_stacksize)
+      if (YYMAXDEPTH <= yystacksize)
 	goto yyoverflowlab;
-      opsc_stacksize *= 2;
-      if (YYMAXDEPTH < opsc_stacksize)
-	opsc_stacksize = YYMAXDEPTH;
+      yystacksize *= 2;
+      if (YYMAXDEPTH < yystacksize)
+	yystacksize = YYMAXDEPTH;
 
       {
-	short *opsc_ss1 = opsc_ss;
+	short int *yyss1 = yyss;
 	union yyalloc *yyptr =
-	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (opsc_stacksize));
+	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyoverflowlab;
-	YYSTACK_RELOCATE (opsc_ss);
-	YYSTACK_RELOCATE (opsc_vs);
+	YYSTACK_RELOCATE (yyss);
+	YYSTACK_RELOCATE (yyvs);
 
 #  undef YYSTACK_RELOCATE
-	if (opsc_ss1 != opsc_ssa)
-	  YYSTACK_FREE (opsc_ss1);
+	if (yyss1 != yyssa)
+	  YYSTACK_FREE (yyss1);
       }
 # endif
 #endif /* no yyoverflow */
 
-      opsc_ssp = opsc_ss + opsc_size - 1;
-      opsc_vsp = opsc_vs + opsc_size - 1;
+      yyssp = yyss + yysize - 1;
+      yyvsp = yyvs + yysize - 1;
 
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-		  (unsigned long int) opsc_stacksize));
+		  (unsigned long int) yystacksize));
 
-      if (opsc_ss + opsc_stacksize - 1 <= opsc_ssp)
+      if (yyss + yystacksize - 1 <= yyssp)
 	YYABORT;
     }
 
-  YYDPRINTF ((stderr, "Entering state %d\n", opsc_state));
+  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
   goto yybackup;
 
@@ -931,36 +948,36 @@ yybackup:
 
   /* First try to decide what to do without reference to lookahead token.  */
 
-  yyn = opsc_pact[opsc_state];
+  yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
-    goto opsc_default;
+    goto yydefault;
 
   /* Not known => get a lookahead token if don't already have one.  */
 
   /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
-  if (opsc_char == YYEMPTY)
+  if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
-      opsc_char = YYLEX;
+      yychar = YYLEX;
     }
 
-  if (opsc_char <= YYEOF)
+  if (yychar <= YYEOF)
     {
-      opsc_char = yytoken = YYEOF;
+      yychar = yytoken = YYEOF;
       YYDPRINTF ((stderr, "Now at end of input.\n"));
     }
   else
     {
-      yytoken = YYTRANSLATE (opsc_char);
-      YYDSYMPRINTF ("Next token is", yytoken, &opsc_lval, &opsc_lloc);
+      yytoken = YYTRANSLATE (yychar);
+      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
      detect an error, take that action.  */
   yyn += yytoken;
-  if (yyn < 0 || YYLAST < yyn || opsc_check[yyn] != yytoken)
-    goto opsc_default;
-  yyn = opsc_table[yyn];
+  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
+    goto yydefault;
+  yyn = yytable[yyn];
   if (yyn <= 0)
     {
       if (yyn == 0 || yyn == YYTABLE_NINF)
@@ -976,10 +993,10 @@ yybackup:
   YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));
 
   /* Discard the token being shifted unless it is eof.  */
-  if (opsc_char != YYEOF)
-    opsc_char = YYEMPTY;
+  if (yychar != YYEOF)
+    yychar = YYEMPTY;
 
-  *++opsc_vsp = opsc_lval;
+  *++yyvsp = yylval;
 
 
   /* Count tokens shifted since error; after three, turn off error
@@ -987,15 +1004,15 @@ yybackup:
   if (yyerrstatus)
     yyerrstatus--;
 
-  opsc_state = yyn;
+  yystate = yyn;
   goto yynewstate;
 
 
 /*-----------------------------------------------------------.
-| opsc_default -- do the default action for the current state.  |
+| yydefault -- do the default action for the current state.  |
 `-----------------------------------------------------------*/
-opsc_default:
-  yyn = opsc_defact[opsc_state];
+yydefault:
+  yyn = yydefact[yystate];
   if (yyn == 0)
     goto yyerrlab;
   goto yyreduce;
@@ -1006,7 +1023,7 @@ opsc_default:
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
-  opsc_len = yyr2[yyn];
+  yylen = yyr2[yyn];
 
   /* If YYLEN is nonzero, implement the default value of the action:
      `$$ = $1'.
@@ -1016,81 +1033,83 @@ yyreduce:
      users should not rely upon it.  Assigning to YYVAL
      unconditionally makes the parser a bit smaller, and it avoids a
      GCC warning that YYVAL may be used uninitialized.  */
-  opsc_val = opsc_vsp[1-opsc_len];
+  yyval = yyvsp[1-yylen];
 
 
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
         case 2:
-
-    { setTags( opsc_vsp[0].tags ) ; }
+#line 66 "./optparser.yy"
+    { setTags( yyvsp[0].tags ) ; }
     break;
 
   case 3:
-
-    { add_tag( opsc_vsp[-1].tags, opsc_vsp[0].tag ) ; }
+#line 69 "./optparser.yy"
+    { add_tag( yyvsp[-1].tags, yyvsp[0].tag ) ; }
     break;
 
   case 4:
-
-    { opsc_val.tags = new Tags() ; opsc_val.tags->AddTag( opsc_vsp[0].tag ) ;  }
+#line 70 "./optparser.yy"
+    { yyval.tags = new Tags() ; yyval.tags->AddTag( yyvsp[0].tag ) ;  }
     break;
 
   case 5:
-
+#line 74 "./optparser.yy"
     {
-                 printMessage( opsc_vsp[-1].string ) ;
-                 printMessage( opsc_vsp[0].string ) ;
+                 printMessage( *yyvsp[-1].string ) ;
+                 printMessage( *yyvsp[0].string ) ;
              }
     break;
 
   case 6:
-
+#line 79 "./optparser.yy"
     {
-	       opsc_val.tag = new Tag( opsc_vsp[-4].string, opsc_vsp[-3].string ) ;
-               opsc_val.tag->SetFlags(opsc_vsp[-1].flag) ;
+	       yyval.tag = new Tag( *yyvsp[-4].string, *yyvsp[-3].string ) ;
+               yyval.tag->SetFlags(yyvsp[-1].flag) ;
+               delete yyvsp[-4].string;
+               delete yyvsp[-3].string;
 	     }
     break;
 
   case 7:
-
-    { opsc_val.flag = opsc_vsp[-2].flag | opsc_vsp[0].flag ; }
+#line 87 "./optparser.yy"
+    { yyval.flag = yyvsp[-2].flag | yyvsp[0].flag ; }
     break;
 
   case 9:
-
-    { opsc_val.flag = 0 ; printMessage( " (no options) " ) ; }
+#line 91 "./optparser.yy"
+    { yyval.flag = 0 ; printMessage( " (no options) " ) ; }
     break;
 
   case 10:
-
-    { printMessage( " - bold" ) ; opsc_val.flag = ISBOLD ; }
+#line 92 "./optparser.yy"
+    { printMessage( " - bold" ) ; yyval.flag = ISBOLD ; }
     break;
 
   case 11:
-
-    { printMessage( " - italics" ) ; opsc_val.flag = ISITALIC ; }
+#line 93 "./optparser.yy"
+    { printMessage( " - italics" ) ; yyval.flag = ISITALIC ; }
     break;
 
   case 12:
-
-    { printMessage( " - underline" ) ; opsc_val.flag = ISUNDERLINE ; }
+#line 94 "./optparser.yy"
+    { printMessage( " - underline" ) ; yyval.flag = ISUNDERLINE ; }
     break;
 
 
     }
 
-/* Line 999 of yacc.c.  */
-
+/* Line 1010 of yacc.c.  */
+#line 1105 "optparser.cc"
 
-  opsc_vsp -= opsc_len;
-  opsc_ssp -= opsc_len;
+  yyvsp -= yylen;
+  yyssp -= yylen;
 
 
-  YY_STACK_PRINT (opsc_ss, opsc_ssp);
+  YY_STACK_PRINT (yyss, yyssp);
 
-  *++opsc_vsp = opsc_val;
+  *++yyvsp = yyval;
 
 
   /* Now `shift' the result of the reduction.  Determine what state
@@ -1099,11 +1118,11 @@ yyreduce:
 
   yyn = yyr1[yyn];
 
-  opsc_state = opsc_pgoto[yyn - YYNTOKENS] + *opsc_ssp;
-  if (0 <= opsc_state && opsc_state <= YYLAST && opsc_check[opsc_state] == *opsc_ssp)
-    opsc_state = opsc_table[opsc_state];
+  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
+  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
+    yystate = yytable[yystate];
   else
-    opsc_state = opsc_defgoto[yyn - YYNTOKENS];
+    yystate = yydefgoto[yyn - YYNTOKENS];
 
   goto yynewstate;
 
@@ -1115,55 +1134,67 @@ yyerrlab:
   /* If not already recovering from an error, report this error.  */
   if (!yyerrstatus)
     {
-      ++opsc_nerrs;
+      ++yynerrs;
 #if YYERROR_VERBOSE
-      yyn = opsc_pact[opsc_state];
+      yyn = yypact[yystate];
 
       if (YYPACT_NINF < yyn && yyn < YYLAST)
 	{
-	  YYSIZE_T opsc_size = 0;
-	  int yytype = YYTRANSLATE (opsc_char);
+	  YYSIZE_T yysize = 0;
+	  int yytype = YYTRANSLATE (yychar);
+	  const char* yyprefix;
 	  char *yymsg;
-	  int yyx, yycount;
+	  int yyx;
 
-	  yycount = 0;
 	  /* Start YYX at -YYN if negative to avoid negative indexes in
 	     YYCHECK.  */
-	  for (yyx = yyn < 0 ? -yyn : 0;
-	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
-	    if (opsc_check[yyx + yyn] == yyx && yyx != YYTERROR)
-	      opsc_size += opsc_strlen (yytname[yyx]) + 15, yycount++;
-	  opsc_size += opsc_strlen ("syntax error, unexpected ") + 1;
-	  opsc_size += opsc_strlen (yytname[yytype]);
-	  yymsg = (char *) YYSTACK_ALLOC (opsc_size);
+	  int yyxbegin = yyn < 0 ? -yyn : 0;
+
+	  /* Stay within bounds of both yycheck and yytname.  */
+	  int yychecklim = YYLAST - yyn;
+	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
+	  int yycount = 0;
+
+	  yyprefix = ", expecting ";
+	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
+	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
+	      {
+		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
+		yycount += 1;
+		if (yycount == 5)
+		  {
+		    yysize = 0;
+		    break;
+		  }
+	      }
+	  yysize += (sizeof ("syntax error, unexpected ")
+		     + yystrlen (yytname[yytype]));
+	  yymsg = (char *) YYSTACK_ALLOC (yysize);
 	  if (yymsg != 0)
 	    {
-	      char *yyp = opsc_stpcpy (yymsg, "syntax error, unexpected ");
-	      yyp = opsc_stpcpy (yyp, yytname[yytype]);
+	      char *yyp = yystpcpy (yymsg, "syntax error, unexpected ");
+	      yyp = yystpcpy (yyp, yytname[yytype]);
 
 	      if (yycount < 5)
 		{
-		  yycount = 0;
-		  for (yyx = yyn < 0 ? -yyn : 0;
-		       yyx < (int) (sizeof (yytname) / sizeof (char *));
-		       yyx++)
-		    if (opsc_check[yyx + yyn] == yyx && yyx != YYTERROR)
+		  yyprefix = ", expecting ";
+		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
+		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
 		      {
-			const char *yyq = ! yycount ? ", expecting " : " or ";
-			yyp = opsc_stpcpy (yyp, yyq);
-			yyp = opsc_stpcpy (yyp, yytname[yyx]);
-			yycount++;
+			yyp = yystpcpy (yyp, yyprefix);
+			yyp = yystpcpy (yyp, yytname[yyx]);
+			yyprefix = " or ";
 		      }
 		}
-	      opsc_error (yymsg);
+	      yyerror (yymsg);
 	      YYSTACK_FREE (yymsg);
 	    }
 	  else
-	    opsc_error ("syntax error; also virtual memory exhausted");
+	    yyerror ("syntax error; also virtual memory exhausted");
 	}
       else
 #endif /* YYERROR_VERBOSE */
-	opsc_error ("syntax error");
+	yyerror ("syntax error");
     }
 
 
@@ -1173,25 +1204,27 @@ yyerrlab:
       /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
-      /* Return failure if at end of input.  */
-      if (opsc_char == YYEOF)
+      if (yychar <= YYEOF)
         {
-	  /* Pop the error token.  */
-          YYPOPSTACK;
-	  /* Pop the rest of the stack.  */
-	  while (opsc_ss < opsc_ssp)
-	    {
-	      YYDSYMPRINTF ("Error: popping", opsc_stos[*opsc_ssp], opsc_vsp, yylsp);
-	      yydestruct (opsc_stos[*opsc_ssp], opsc_vsp);
-	      YYPOPSTACK;
-	    }
-	  YYABORT;
+          /* If at end of input, pop the error token,
+	     then the rest of the stack, then return failure.  */
+	  if (yychar == YYEOF)
+	     for (;;)
+	       {
+		 YYPOPSTACK;
+		 if (yyssp == yyss)
+		   YYABORT;
+		 YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+		 yydestruct (yystos[*yyssp], yyvsp);
+	       }
         }
+      else
+	{
+	  YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
+	  yydestruct (yytoken, &yylval);
+	  yychar = YYEMPTY;
 
-      YYDSYMPRINTF ("Error: discarding", yytoken, &opsc_lval, &opsc_lloc);
-      yydestruct (yytoken, &opsc_lval);
-      opsc_char = YYEMPTY;
-
+	}
     }
 
   /* Else will try to reuse lookahead token after shifting the error
@@ -1199,36 +1232,53 @@ yyerrlab:
   goto yyerrlab1;
 
 
-/*----------------------------------------------------.
-| yyerrlab1 -- error raised explicitly by an action.  |
-`----------------------------------------------------*/
+/*---------------------------------------------------.
+| yyerrorlab -- error raised explicitly by YYERROR.  |
+`---------------------------------------------------*/
+yyerrorlab:
+
+#ifdef __GNUC__
+  /* Pacify GCC when the user code never invokes YYERROR and the label
+     yyerrorlab therefore never appears in user code.  */
+  if (0)
+     goto yyerrorlab;
+#endif
+
+  yyvsp -= yylen;
+  yyssp -= yylen;
+  yystate = *yyssp;
+  goto yyerrlab1;
+
+
+/*-------------------------------------------------------------.
+| yyerrlab1 -- common code for both syntax error and YYERROR.  |
+`-------------------------------------------------------------*/
 yyerrlab1:
   yyerrstatus = 3;	/* Each real token shifted decrements this.  */
 
   for (;;)
     {
-      yyn = opsc_pact[opsc_state];
+      yyn = yypact[yystate];
       if (yyn != YYPACT_NINF)
 	{
 	  yyn += YYTERROR;
-	  if (0 <= yyn && yyn <= YYLAST && opsc_check[yyn] == YYTERROR)
+	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
 	    {
-	      yyn = opsc_table[yyn];
+	      yyn = yytable[yyn];
 	      if (0 < yyn)
 		break;
 	    }
 	}
 
       /* Pop the current state because it cannot handle the error token.  */
-      if (opsc_ssp == opsc_ss)
+      if (yyssp == yyss)
 	YYABORT;
 
-      YYDSYMPRINTF ("Error: popping", opsc_stos[*opsc_ssp], opsc_vsp, yylsp);
-      yydestruct (opsc_stos[opsc_state], opsc_vsp);
-      opsc_vsp--;
-      opsc_state = *--opsc_ssp;
-
-      YY_STACK_PRINT (opsc_ss, opsc_ssp);
+      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+      yydestruct (yystos[yystate], yyvsp);
+      YYPOPSTACK;
+      yystate = *yyssp;
+      YY_STACK_PRINT (yyss, yyssp);
     }
 
   if (yyn == YYFINAL)
@@ -1236,10 +1286,10 @@ yyerrlab1:
 
   YYDPRINTF ((stderr, "Shifting error token, "));
 
-  *++opsc_vsp = opsc_lval;
+  *++yyvsp = yylval;
 
 
-  opsc_state = yyn;
+  yystate = yyn;
   goto yynewstate;
 
 
@@ -1262,86 +1312,41 @@ yyabortlab:
 | yyoverflowlab -- parser overflow comes here.  |
 `----------------------------------------------*/
 yyoverflowlab:
-  opsc_error ("parser stack overflow");
+  yyerror ("parser stack overflow");
   yyresult = 2;
   /* Fall through.  */
 #endif
 
 yyreturn:
 #ifndef yyoverflow
-  if (opsc_ss != opsc_ssa)
-    YYSTACK_FREE (opsc_ss);
+  if (yyss != yyssa)
+    YYSTACK_FREE (yyss);
 #endif
   return yyresult;
 }
 
 
+#line 97 "./optparser.yy"
 
 
-
-// this should be passed by the compiler
-#ifndef SOURCE_HIGHLIGHT_DATA_DIR
-#define SOURCE_HIGHLIGHT_DATA_DIR "."
-#endif
-
-#define TAGS_FILE "tags.j2h"
-
-extern char *tags_file;
 char *current_file = 0;
 
 void
-parseTags()
+parseTags(const string &path, const string &name)
 {
-  // opens the file for opsc_lex
-  opsc_in = openTagsFile() ;
-  if (! opsc_in) {
-    printWarning( "No tags.j2h file, using defaults ...", cerr ) ;
-    setTags( NULL ) ;
-    return ;
-  }
+  // opens the file for yylex
+  opsc_in = open_data_file_stream(path, name);
 
   printMessage_noln( "Parsing ", cerr ) ;
-  if (tags_file) {
-    printMessage_noln (tags_file, cerr);
-  } else {
-    printMessage_noln (TAGS_FILE, cerr);
-  }
+  printMessage_noln (name, cerr);
   printMessage( " file ...", cerr ) ;
-  opsc_parse() ;
+  yyparse() ;
   printMessage( "Parsing done!", cerr ) ;
-}
-
-FILE *
-openTagsFile()
-{
-  FILE *file = 0;
-
-  printMessage( "Trying with..." ) ;
-
-  if ( tags_file )
-    {
-      printMessage (tags_file);
-      file = fopen (tags_file, "r");
-      current_file = tags_file;
-      if (file)
-        return file;
-    }
-
-  printMessage( TAGS_FILE ) ;
-  file = fopen( TAGS_FILE, "r") ;
-  current_file = TAGS_FILE;
-  if ( file )
-    return file ;
-
-  file = fopen( SOURCE_HIGHLIGHT_DATA_DIR "/" TAGS_FILE, "r") ;
-  printMessage( SOURCE_HIGHLIGHT_DATA_DIR "/" TAGS_FILE ) ;
-  current_file = SOURCE_HIGHLIGHT_DATA_DIR "/" TAGS_FILE;
-
-  return file ;
+  fclose(opsc_in);
 }
 
 void
-opsc_error( char *s )
+yyerror( char *s )
 {
   ostringstream str ;
   str << current_file << ":" << line << ": " << s << ", in option declaration";
@@ -1354,6 +1359,6 @@ add_tag(Tags *tags, Tag *t)
 {
   if (! tags->AddTag(t))
   {
-    opsc_error("already defined");
+    yyerror("already defined");
   }
 }
