@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875.  */
+/* A Bison parser, made by GNU Bison 1.875d.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -46,17 +46,17 @@
 
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-
+#line 49 "./optparser.yy"
 typedef union YYSTYPE {
   int tok ; /* command */
-  char * string ; /* string : id, ... */
+  const std::string * string ; /* string : id, ... */
   int flag ;
   Tag *tag ;
   Tags *tags ;
 } YYSTYPE;
-/* Line 1240 of yacc.c.  */
-
-# define opsc_stype YYSTYPE /* obsolescent; will be withdrawn */
+/* Line 1285 of yacc.c.  */
+#line 59 "optparser.h"
+# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
 #endif
