@@ -20,19 +20,15 @@
 #include <iostream>
 
 #include "textgen.h"
-#include "chartranslator.h"
-#include "maingeneratorfactory.h"
 
 using namespace std;
 
-TextGenerator::TextGenerator() :
-  char_translator (generator_factory->getCharTranslator())
+TextGenerator::TextGenerator() 
 {
 }
 
-TextGenerator::TextGenerator(const std::string &pre, const std::string &post) : 
-  pre_tag(pre), post_tag(post),
-  char_translator (generator_factory->getCharTranslator())
+TextGenerator::TextGenerator(const std::string &pre, const std::string &post) :
+  pre_tag(pre), post_tag(post)
 {
 }
 
@@ -68,6 +64,12 @@ TextGenerator::generate(const char *s)
   return outstream.str();
 }
 
+string
+TextGenerator::generate(const string &s)
+{
+  return generate(s.c_str());
+}
+
 string
 TextGenerator::generate( const string &s, int start, int end )
 {
@@ -76,21 +78,6 @@ TextGenerator::generate( const string &s, int start, int end )
   return outstream.str();
 }
 
-void
-TextGenerator::preprocess(const char *s)
-{
-  char_translator->translate (&outstream, s);
-}
-
-// this version preprocess the string for some special characters
-string
-TextGenerator::generate_preproc(const char *s)
-{
-  reset();
-  preprocess(s);
-  return outstream.str();
-}
-
 string
 TextGenerator::generateln( const char *s )
 {
@@ -104,31 +91,47 @@ TextGenerator::generateEntire( const char *s )
 {
   reset();
   startTextGeneration() ;
-  preprocess(s) ;
+  output(s);
   endTextGeneration() ;
   return outstream.str();
 }
 
+string
+TextGenerator::generateEntire( const string &s )
+{
+  return generateEntire(s.c_str());
+}
+
 string
 TextGenerator::beginText( const char *s )
 {
   reset();
   startTextGeneration() ;
-  if ( s )
-    preprocess( s ) ;
+  output(s);
   return outstream.str();
 }
 
+string
+TextGenerator::beginText( const string &s )
+{
+  return beginText(s.c_str());
+}
+
 string
 TextGenerator::endText( const char *s )
 {
   reset();
-  if ( s )
-    preprocess( s ) ;
+  output(s);
   endTextGeneration() ;
   return outstream.str();
 }
 
+string
+TextGenerator::endText( const string &s )
+{
+  return endText(s.c_str());
+}
+
 string
 TextGenerator::get_string()
 {
