@@ -20,23 +20,44 @@
 #ifndef _STARTAPP_H
 #define _STARTAPP_H
 
+#include <string>
+
+class TextFormatter;
+class DocGenerator;
+class LangMap;
+class GeneratorFactory;
+
 class StartApp
 {
  protected:
   char *inputFileName, *outputFileName; /* what we're reading  */
-  
+  DocGenerator *docgenerator;
+  TextFormatter *formatter;
+  LangMap *langmap;
+  GeneratorFactory *generator_factory;
+
   int entire_doc; // we want a real html doc
   short verbose;
   char *cssUrl;
   int use_css; // Use CSS instead of font-tags
   int is_cgi;   // set if in CGI mode (and therefore has to add CGI-header)
-  
+  bool gen_version;
+  bool generate_line_num;
+  bool generate_ref;
+
+  std::string data_dir;
+  std::string lang_file;
+  std::string source_language;
+
   virtual void print_copyright();
   virtual void print_reportbugs();
   virtual void print_version();
 
+  int processFile(const std::string &inputFileName, const std::string &outputFileName) ;
+
  public:
   StartApp();
+  virtual ~StartApp();
 
   virtual int start(int argc, char * argv[]);
 } ;
