@@ -15,8 +15,19 @@
   http://www.gnu.org/software/src-highlite
 */
 
+package hello;
+
 import java.io.* ;
 
+/**
+ * <p>
+ * A simple Hello World class, used to demonstrate some
+ * features of Java source highlighting.
+ * </p>
+ *
+ * @author Lorenzo Bettini
+ * @version 2.0
+ */
 public class Hello {
     int foo = 1998 ;
     int hex_foo = 0xCAFEBABE;
